<?php
/**
 * Plugin Name: Instruction Bar for CPB
 * Plugin URI: https://www.wisdmlabs.com/assorted-bundles-woocommerce-custom-product-boxes-plugin/
 * Description: The Instruction Bar for CPB is an extension for your Custom Product Boxes plugin, using which, your admin will be able to show Instruction bar on his product page.
 * Version: 1.0
 * Author: WisdmLabs
 * Author URI: http://www.wisdmlabs.com
 * Text Domain: custom-product-boxes
 *
 * @package CPB
 */

// Exit if accessed directly.
defined( 'ABSPATH' ) || exit;
// Define plugin constants.
// constant version.

if( function_exists('acf_add_local_field_group') ):

acf_add_local_field_group(array(
	'key' => 'group_5f9ad1f09a011',
	'title' => 'cpb_addon_instruction',
	'fields' => array(
		array(
			'key' => 'field_5f9ad1f845aa8',
			'label' => 'CPB Instruction Text',
			'name' => 'cpb_instruction_text',
			'type' => 'text',
			'instructions' => '',
			'required' => 0,
			'conditional_logic' => 0,
			'wrapper' => array(
				'width' => '',
				'class' => '',
				'id' => '',
			),
			'default_value' => 'Add your favourite addon to the custom box 2',
			'placeholder' => 'Add the instruction text you want to show your user',
			'prepend' => '',
			'append' => '',
			'maxlength' => '',
		),
	),
	'location' => array(
		array(
			array(
				'param' => 'post_taxonomy',
				'operator' => '==',
				'value' => 'product_type:wdm_bundle_product',
			),
		),
	),
	'menu_order' => 0,
	'position' => 'normal',
	'style' => 'seamless',
	'label_placement' => 'top',
	'instruction_placement' => 'field',
	'hide_on_screen' => '',
	'active' => true,
	'description' => '',
));

endif;

if( ! function_exists('cpb_addon_selection_instruction_text_function') ) {
	/**
	 * Filters the text to show before instruction before box.
	 *
	 * @since  4.1.0
	 * @param  string  $text  Default Instruction text.
	 * @return string $text
	 */
	function cpb_addon_selection_instruction_text_function( $text ) {
		global $product;

		return ! $product->is_type( 'wdm_bundle_product' ) ? $text : get_post_meta( $product->get_id(), 'cpb_instruction_text', true );
	}
	add_filter( 'cpb_addon_selection_instruction_text', 'cpb_addon_selection_instruction_text_function' );
}

if( ! function_exists('cpb_before_box_instruction_function') ) {
	/**
	 * Get HTML to show instruction before box.
	 *
	 * @since  4.1.0
	 * @param  object $cpb_product Box product object.
	 * @param  array  $addon_list  List of addons.
	 * @return void
	 */
	function cpb_before_box_instruction_function( $cpb_product, $addon_list ) {
		if ( ! $cpb_product->is_type( 'wdm_bundle_product' ) || '' == get_post_meta( $cpb_product->get_id(), 'cpb_instruction_text', true ) ) {
			return;
		}

		wc_get_template(
			'/single-product/cpb-before-box-instruction.php',
			array(),
			'custom-product-boxes/',
			CPB()->plugin_path() . '/templates/' . CPB()->cpb_template_folder()
		);
	}
	add_action( 'cpb_before_box_wrap', 'cpb_before_box_instruction_function', 10, 2 );
}
